==> print-manager-14.12.1.tar.xz: print-manager-14.12.1/printqueue/PrintQueue.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Daniel Nicoletti                                *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef PRINT_QUEUE_H
#define PRINT_QUEUE_H

#include <KUniqueApplication>

class PrintQueue : public KUniqueApplication
{
    Q_OBJECT
public:
    PrintQueue();
    virtual ~PrintQueue();
    int newInstance();

    void showQueue(const QString &destName);

public slots:
    void removeQueue();

private:
    QHash<QString, QWidget *> m_uis;
};

#endif

==> print-manager-18.12.2.tar.xz: print-manager-18.12.2/printqueue/PrintQueue.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Daniel Nicoletti                                *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef PRINT_QUEUE_H
#define PRINT_QUEUE_H

#include <QApplication>

class PrintQueue : public QApplication
{
    Q_OBJECT
public:
    PrintQueue(int & argc, char ** argv);
    virtual ~PrintQueue();

public slots:
    void showQueues(const QStringList & queues, const QString & cwd = QString());

private slots:
    void removeQueue();

private:
    void showQueue(const QString &destName);
    QHash<QString, QWidget *> m_uis;
};

#endif
